//////////////////////////////////////////////////////////////////////////
//
// pgAdmin III - PostgreSQL Tools
// RCS-ID:      $Id: dlgGroup.h,v 1.6 2004/07/20 12:38:04 andreas Exp $
// Copyright (C) 2002 - 2004, The pgAdmin Development Team
// This software is released under the Artistic Licence
//
// dlgGroup.h - Group property 
//
//////////////////////////////////////////////////////////////////////////


#ifndef __DLG_GROUPPROP
#define __DLG_GROUPPROP

#include "dlgProperty.h"

class pgGroup;

class dlgGroup : public dlgProperty
{
public:
    dlgGroup(frmMain *frame, pgGroup *node=0);
    wxString GetSql();
    pgObject *CreateObject(pgCollection *collection);
    pgObject *GetObject();

    void CheckChange();
    int Go(bool modal);

private:
    pgGroup *group;

    void OnUserAdd(wxCommandEvent &ev);
    void OnUserRemove(wxCommandEvent &ev);

    wxArrayString usersIn;

    DECLARE_EVENT_TABLE();
};


#endif
